@@ -1,9 +1,9 @@
-from typing import Protocol, Any
+from typing import Any
 
 import numpy as np
 
 
-class Threshold(Protocol):
+class Threshold():
     """Base class for thresholders
 
     Preprocessor object must take a `fit()` method as well as `get_threshold()`.
